@@ -45,7 +45,7 @@ public:
     virtual void mouseMoveEvent(KoPointerEvent *event);
     /// reimplemented
     virtual void mouseReleaseEvent(KoPointerEvent *event);
-signals:
+Q_SIGNALS:
     void shapeChanged(WebShape*);
 protected:
     virtual QList<QPointer<QWidget> > createOptionWidgets();
