@@ -137,4 +137,14 @@ void KRITAIMAGE_EXPORT kis_debug_save_device_incremental(KisPaintDeviceSP device
     } while(0)
 
 
+
+#ifdef __GNUC__
+KRITAIMAGE_EXPORT const char* __methodName(const char *prettyFunction);
+#define __METHOD_NAME__ __methodName(__PRETTY_FUNCTION__)
+#else
+#define __METHOD_NAME__ "<unknown>:<unknown>"
+#endif
+
+#define PREPEND_METHOD(msg) QString("%1: %2").arg(__METHOD_NAME__).arg(msg)
+
 #include "kis_assert.h"
