@@ -131,6 +131,8 @@ public:
      */
     KisPaintDeviceSP projection() const;
 
+    KisAbstractProjectionPlaneSP projectionPlane() const;
+
     /**
      * Change the selection to the specified selection object. The
      * selection is deep copied.
@@ -185,6 +187,9 @@ protected:
                                const QRect & rc,
                                PositionToFilthy maskPos) const;
 
+private:
+    friend class KisMaskProjectionPlane;
+
 private:
 
     struct Private;
