@@ -103,6 +103,7 @@ KisColorSelectorBase::KisColorSelectorBase(QWidget *parent) :
     m_popupOnMouseClick(true),
     m_colorSpace(0),
     m_isPopup(false),
+    m_hideOnMouseClick(false),
     m_colorPreviewPopup(new KisColorPreviewPopup(this))
 {
     m_hideTimer->setInterval(0);
@@ -216,6 +217,9 @@ void KisColorSelectorBase::mouseReleaseEvent(QMouseEvent *e) {
 
     if (e->button() == Qt::MidButton) {
         e->accept();
+    } else if (m_isPopup && m_hideOnMouseClick==true && !m_hideTimer->isActive()) {
+        showColorPreview();
+        hide();
     }
 }
 
@@ -445,6 +449,7 @@ void KisColorSelectorBase::updateSettings()
 
 
     if(m_isPopup) {
+        m_hideOnMouseClick = cfg.readEntry("hidePopupOnClickCheck", false);
         resize(cfg.readEntry("zoomSize", 280), cfg.readEntry("zoomSize", 280));
     }
 
