@@ -123,8 +123,6 @@ KisLayerBox::KisLayerBox()
 {
     KisConfig cfg;
 
-    setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
-
     QWidget* mainWidget = new QWidget(this);
     setWidget(mainWidget);
     m_opacityDelayTimer.setSingleShot(true);
@@ -260,7 +258,7 @@ KisLayerBox::KisLayerBox()
     connect(m_nodeModel, SIGNAL(rowsRemoved(const QModelIndex&, int, int)), SLOT(updateUI()));
     connect(m_nodeModel, SIGNAL(rowsMoved(const QModelIndex&, int, int, const QModelIndex&, int)), SLOT(updateUI()));
     connect(m_nodeModel, SIGNAL(dataChanged(const QModelIndex&, const QModelIndex&)), SLOT(updateUI()));
-    connect(m_nodeModel, SIGNAL(modelReset()), SLOT(updateUI()));
+    connect(m_nodeModel, SIGNAL(modelReset()), SLOT(slotModelReset()));
 
     KisAction *showGlobalSelectionMask = new KisAction(i18n("&Show Global Selection Mask"), this);
     showGlobalSelectionMask->setObjectName("show-global-selection-mask");
@@ -321,7 +319,11 @@ void KisLayerBox::setMainWindow(KisViewManager* kisview)
 
 void KisLayerBox::setCanvas(KoCanvasBase *canvas)
 {
+    if(m_canvas == canvas)
+        return;
+
     setEnabled(canvas != 0);
+
     if (m_canvas) {
         m_canvas->disconnectCanvasObserver(this);
         m_nodeModel->setDummiesFacade(0, 0, 0);
@@ -330,6 +332,7 @@ void KisLayerBox::setCanvas(KoCanvasBase *canvas)
         disconnect(m_nodeManager, 0, this, 0);
         disconnect(m_nodeModel, 0, m_nodeManager, 0);
         disconnect(m_nodeModel, SIGNAL(nodeActivated(KisNodeSP)), this, SLOT(updateUI()));
+        m_nodeManager->setSelectedNodes(QList<KisNodeSP>());
     }
 
     m_canvas = dynamic_cast<KisCanvas2*>(canvas);
@@ -400,13 +403,11 @@ void KisLayerBox::unsetCanvas()
         m_newLayerMenu->clear();
     }
     setCanvas(0);
-    m_nodeManager->setSelectedNodes(QList<KisNodeSP>());
 }
 
 void KisLayerBox::notifyImageDeleted()
 {
     setCanvas(0);
-    m_nodeManager->setSelectedNodes(QList<KisNodeSP>());
 }
 
 void KisLayerBox::updateUI()
@@ -469,6 +470,24 @@ void KisLayerBox::setCurrentNode(KisNodeSP node)
     updateUI();
 }
 
+void KisLayerBox::slotModelReset()
+{
+    if(m_nodeModel->hasDummiesFacade()) {
+        QItemSelection selection;
+        foreach(const KisNodeSP node, m_nodeManager->selectedNodes()) {
+            const QModelIndex &idx = m_nodeModel->indexFromNode(node);
+            if(idx.isValid()){
+                QItemSelectionRange selectionRange(idx);
+                selection << selectionRange;
+            }
+        }
+
+        m_wdgLayerBox->listLayers->selectionModel()->select(selection, QItemSelectionModel::ClearAndSelect);
+    }
+
+    updateUI();
+}
+
 void KisLayerBox::slotSetCompositeOp(const KoCompositeOp* compositeOp)
 {
     KoID opId = KoCompositeOpRegistry::instance().getKoID(compositeOp->id());
