@@ -46,17 +46,19 @@ K_PLUGIN_FACTORY(ImageSizeFactory, registerPlugin<ImageSize>();)
 K_EXPORT_PLUGIN(ImageSizeFactory("krita"))
 
 ImageSize::ImageSize(QObject *parent, const QVariantList &)
-        : KisViewPlugin(parent, "kritaplugins/imagesize.rc")
+        : KisViewPlugin(parent)
 {
-    KisAction *action  = new KisAction(i18n("Scale To New Size..."), this);
+    KisAction *action  = new KisAction(i18n("Scale Image To New Size..."), this);
+    action->setActivationFlags(KisAction::ACTIVE_NODE);
     addAction("imagesize", action);
     connect(action, SIGNAL(triggered()), this, SLOT(slotImageSize()));
 
-    action = new KisAction(i18n("Size Canvas..."), this);
+    action = new KisAction(i18n("Resize Canvas..."), this);
+    action->setActivationFlags(KisAction::ACTIVE_NODE);
     addAction("canvassize", action);
     connect(action, SIGNAL(triggered()), this, SLOT(slotCanvasSize()));
 
-    action = new KisAction(i18n("Scale &Layer..."), this);
+    action = new KisAction(i18n("Scale &Layer to new Size..."), this);
     action->setActivationFlags(KisAction::ACTIVE_LAYER);
     action->setActivationConditions(KisAction::ACTIVE_NODE_EDITABLE);
     addAction("layersize", action);
@@ -127,7 +129,7 @@ void ImageSize::slotLayerSize()
 
     DlgLayerSize * dlgLayerSize = new DlgLayerSize(m_view->mainWindow(), "LayerSize", rc.width(), rc.height(), image->yRes());
     Q_CHECK_PTR(dlgLayerSize);
-    dlgLayerSize->setCaption(i18n("Layer Size"));
+    dlgLayerSize->setCaption(i18n("Resize Layer"));
 
     if (dlgLayerSize->exec() == QDialog::Accepted) {
         qint32 w = dlgLayerSize->width();
@@ -154,7 +156,7 @@ void ImageSize::slotSelectionScale()
 
     KIS_ASSERT_RECOVER_RETURN(selectionMask);
 
-    QRect rc = selectionMask->selection()->selectedRect();
+    QRect rc = selectionMask->selection()->selectedExactRect();
     DlgLayerSize * dlgSize = new DlgLayerSize(m_view->mainWindow(), "SelectionScale", rc.width(), rc.height(), image->yRes());
     dlgSize->setCaption(i18n("Scale Selection"));
 
