@@ -16,7 +16,7 @@
  */
 
 #include "DodgeBurn.h"
-#include <filter/kis_filter_configuration.h>
+#include <filter/kis_color_transformation_configuration.h>
 #include <kis_paint_device.h>
 
 #include "ui_DodgeBurnConfigurationBaseWidget.h"
@@ -74,7 +74,7 @@ KisDodgeBurnConfigWidget::~KisDodgeBurnConfigWidget()
 
 KisPropertiesConfiguration * KisDodgeBurnConfigWidget::configuration() const
 {
-    KisFilterConfiguration* c = new KisFilterConfiguration(m_id, 0);
+    KisColorTransformationConfiguration* c = new KisColorTransformationConfiguration(m_id, 0);
     int type = 0;
     if(m_page->radioButtonHighlights->isChecked())
     {
