@@ -226,7 +226,6 @@ KisImageBuilder_Result KisJPEGConverter::decode(const KUrl& uri)
     }
 
     // Set resolution
-    qDebug() << "cinfo.X_density" << cinfo.X_density << "cinfo.y_density" << cinfo.Y_density << "unit" << cinfo.density_unit;
     double xres = 72, yres = 72;
     if (cinfo.density_unit == 1) {
         xres = cinfo.X_density;
@@ -412,7 +411,7 @@ KisImageBuilder_Result KisJPEGConverter::decode(const KUrl& uri)
     layer->metaData()->debugDump();
 
     // Check whether the metadata has resolution info, too...
-    if (cinfo.density_unit == 0) {
+    if (cinfo.density_unit == 0 && layer->metaData()->containsEntry("tiff:XResolution") && layer->metaData()->containsEntry("tiff:YResolution")) {
         double xres = layer->metaData()->getEntry("tiff:XResolution").value().asDouble();
         double yres = layer->metaData()->getEntry("tiff:YResolution").value().asDouble();
         if (xres != 0 && yres != 0) {
