@@ -24,28 +24,10 @@
 
 #include <kio/job.h>
 
+#include "kis_png_converter.h"
 #include "kis_types.h"
-class KisDocument;
 
-/**
- * Image import/export plugins can use these results to report about success or failure.
- */
-enum KisImageBuilder_Result {
-    KisImageBuilder_RESULT_FAILURE = -400,
-    KisImageBuilder_RESULT_NOT_EXIST = -300,
-    KisImageBuilder_RESULT_NOT_LOCAL = -200,
-    KisImageBuilder_RESULT_BAD_FETCH = -100,
-    KisImageBuilder_RESULT_INVALID_ARG = -50,
-    KisImageBuilder_RESULT_OK = 0,
-    KisImageBuilder_RESULT_PROGRESS = 1,
-    KisImageBuilder_RESULT_EMPTY = 100,
-    KisImageBuilder_RESULT_BUSY = 150,
-    KisImageBuilder_RESULT_NO_URI = 200,
-    KisImageBuilder_RESULT_UNSUPPORTED = 300,
-    KisImageBuilder_RESULT_INTR = 400,
-    KisImageBuilder_RESULT_PATH = 500,
-    KisImageBuilder_RESULT_UNSUPPORTED_COLORSPACE = 600
-};
+class KisDocument;
 
 class OraConverter : public QObject
 {
