@@ -27,7 +27,7 @@ class KisSmudgeOptionWidget: public KisCurveOptionWidget
     Q_OBJECT
 
 public:
-    KisSmudgeOptionWidget(const QString& label, const QString& sliderLabel, const QString& name, bool checked);
+    KisSmudgeOptionWidget();
 
     virtual void readOptionSetting(const KisPropertiesConfiguration* setting);
 
