@@ -28,10 +28,8 @@
 #include <kis_composite_ops_model.h>
 #include "kis_signals_blocker.h"
 
-
-
 KisCompositeOpOption::KisCompositeOpOption(bool createConfigWidget):
-    KisPaintOpOption(i18n("Blending Mode"), KisPaintOpOption::generalCategory(), true),
+    KisPaintOpOption(KisPaintOpOption::GENERAL, true),
     m_createConfigWidget(createConfigWidget)
 {
     m_checkable         = false;
@@ -54,6 +52,9 @@ KisCompositeOpOption::KisCompositeOpOption(bool createConfigWidget):
         connect(ui.list    , SIGNAL(clicked(const QModelIndex&)), this, SLOT(slotCompositeOpChanged(const QModelIndex&)));
         connect(ui.bnEraser, SIGNAL(toggled(bool))                , this, SLOT(slotEraserToggled(bool)));
     }
+
+    setObjectName("KisCompositeOpOption");
+
 }
 
 KisCompositeOpOption::~KisCompositeOpOption()
