@@ -220,12 +220,16 @@ void KisToolBrush::resetCursorStyle()
     // When the stabilizer is in use, we avoid using the brush outline cursor,
     // because it would hide the real position of the cursor to the user,
     // yielding unexpected results.
-    if (smoothingOptions()->smoothingType() == KisSmoothingOptions::STABILIZER
-        && cursorStyle != CURSOR_STYLE_NO_CURSOR) {
+    if (smoothingOptions()->smoothingType() == KisSmoothingOptions::STABILIZER &&
+        smoothingOptions()->useDelayDistance() &&
+        cursorStyle == CURSOR_STYLE_NO_CURSOR) {
+
         useCursor(KisCursor::roundCursor());
     } else {
         KisToolFreehand::resetCursorStyle();
     }
+
+    overrideCursorIfNotEditable();
 }
 
 // stabilizer brush settings
