@@ -82,6 +82,12 @@ int KisToolLine::flags() const
     return KisTool::FLAG_USES_CUSTOM_COMPOSITEOP|KisTool::FLAG_USES_CUSTOM_PRESET;
 }
 
+void KisToolLine::resetCursorStyle()
+{
+    KisToolPaint::resetCursorStyle();
+
+    overrideCursorIfNotEditable();
+}
 
 void KisToolLine::activate(ToolActivation activation, const QSet<KoShape*> &shapes)
 {
