@@ -261,6 +261,10 @@ public:
 
     void translate(const QPointF &offset);
 
+    void saveContinuedState();
+    void restoreContinuedState();
+    const ToolTransformArgs* continuedTransform() const;
+
 private:
     void clear();
     void init(const ToolTransformArgs& args);
@@ -299,6 +303,13 @@ private:
     bool m_editTransformPoints;
     QSharedPointer<KisLiquifyProperties> m_liquifyProperties;
     QScopedPointer<KisLiquifyTransformWorker> m_liquifyWorker;
+
+    /**
+     * When we continue a transformation, m_continuedTransformation
+     * stores the initial step of our transform. All cancel and revert
+     * operations should revert to it.
+     */
+    QScopedPointer<ToolTransformArgs> m_continuedTransformation;
 };
 
 #endif // TOOL_TRANSFORM_ARGS_H_
