@@ -1843,34 +1843,35 @@ bool KisDocument::completeLoading(KoStore* store)
 
     d->kraLoader->loadBinaryData(store, d->image, url().url(), isStoredExtern());
 
+    bool retval = true;
     if (!d->kraLoader->errorMessages().isEmpty()) {
         setErrorMessage(d->kraLoader->errorMessages().join(".\n"));
-        return false;
+        retval = false;
     }
+    if (retval) {
+        vKisNodeSP preselectedNodes = d->kraLoader->selectedNodes();
+        if (preselectedNodes.size() > 0) {
+            d->preActivatedNode = preselectedNodes.first();
+        }
 
-    vKisNodeSP preselectedNodes = d->kraLoader->selectedNodes();
-    if (preselectedNodes.size() > 0) {
-        d->preActivatedNode = preselectedNodes.first();
+        // before deleting the kraloader, get the list with preloaded assistants and save it
+        d->assistants = d->kraLoader->assistants();
+        d->shapeController->setImage(d->image);
+
+        connect(d->image.data(), SIGNAL(sigImageModified()), this, SLOT(setImageModified()));
+
+        if (d->image) {
+            d->image->initialRefreshGraph();
+        }
+        setAutoSave(KisConfig().autoSaveInterval());
+
+        emit sigLoadingFinished();
     }
 
-    // before deleting the kraloader, get the list with preloaded assistants and save it
-    d->assistants = d->kraLoader->assistants();
-
     delete d->kraLoader;
     d->kraLoader = 0;
 
-    d->shapeController->setImage(d->image);
-
-    connect(d->image.data(), SIGNAL(sigImageModified()), this, SLOT(setImageModified()));
-
-    if (d->image) {
-        d->image->initialRefreshGraph();
-    }
-    setAutoSave(KisConfig().autoSaveInterval());
-
-    emit sigLoadingFinished();
-
-    return true;
+    return retval;
 
 }
 
@@ -1879,10 +1880,10 @@ bool KisDocument::completeSaving(KoStore* store)
     QString uri = url().url();
 
     d->kraSaver->saveBinaryData(store, d->image, url().url(), isStoredExtern(), isAutosaving());
-
+    bool retval = true;
     if (!d->kraSaver->errorMessages().isEmpty()) {
         setErrorMessage(d->kraSaver->errorMessages().join(".\n"));
-        return false;
+        retval = false;
     }
 
     delete d->kraSaver;
@@ -1890,7 +1891,7 @@ bool KisDocument::completeSaving(KoStore* store)
 
     emit sigSavingFinished();
 
-    return true;
+    return retval;
 }
 
 QDomDocument KisDocument::createDomDocument(const QString& tagName, const QString& version) const
@@ -1942,7 +1943,7 @@ bool KisDocument::loadXML(const KoXmlDocument& doc, KoStore */*store*/)
         return false;
     }
 
-    Q_ASSERT(d->kraLoader == 0);
+    if (d->kraLoader) delete d->kraLoader;
     d->kraLoader = new KisKraLoader(this, syntaxVersion);
 
     // Legacy from the multi-image .kra file period.
@@ -1990,7 +1991,7 @@ QDomDocument KisDocument::saveXML()
     root.setAttribute("editor", "Krita");
     root.setAttribute("syntaxVersion", "2");
 
-    Q_ASSERT(d->kraSaver == 0);
+    if (d->kraSaver) delete d->kraSaver;
     d->kraSaver = new KisKraSaver(this);
 
     root.appendChild(d->kraSaver->saveXML(doc, d->image));
