@@ -22,8 +22,6 @@
 #define KIS_TEMPLATE_TREE_H
 
 #include <QList>
-#include <QStringList>
-#include <QPixmap>
 #include <kcomponentdata.h>
 #include "krita_export.h"
 
@@ -34,12 +32,12 @@ class KRITAUI_EXPORT KisTemplateTree
 {
 
 public:
-    KisTemplateTree(const QByteArray &templateType, const KComponentData &instance,
+    KisTemplateTree(const QString &templatesResourcePath, const KComponentData &instance,
                    bool readTree = false);
     ~KisTemplateTree();
 
-    QByteArray templateType() const {
-        return m_templateType;
+    QString templatesResourcePath() const {
+        return m_templatesResourcePath;
     }
     KComponentData componentData() const {
         return m_componentData;
@@ -65,7 +63,7 @@ private:
     void writeTemplate(KisTemplate *t, KisTemplateGroup *group,
                        const QString &localDir);
 
-    QByteArray m_templateType;
+    QString m_templatesResourcePath;
     KComponentData m_componentData;
     QList<KisTemplateGroup*> m_groups;
     KisTemplateGroup *m_defaultGroup;
