@@ -29,6 +29,8 @@
 #include <kis_types.h>
 #include "krita_export.h"
 
+#include "widgets/kis_floating_message.h"
+
 class KisDocument;
 class KisMainWindow;
 class KisPrintJob;
@@ -74,8 +76,6 @@ public:
     KisView(KisDocument *document, KoCanvasResourceManager *resourceManager, KActionCollection *actionCollection, QWidget *parent = 0);
     ~KisView();
 
-    bool shown() const;
-
     KAction *undoAction() const;
     KAction *redoAction() const;
 
@@ -203,6 +203,11 @@ public:
     /// the global selection.
     KisSelectionSP selection();
 
+    void notifyCurrentStateChanged(bool isCurrent);
+
+    void setShowFloatingMessage(bool show);
+    void showFloatingMessageImpl(const QString message, const QIcon& icon, int timeout, KisFloatingMessage::Priority priority, int alignment);
+
 public Q_SLOTS:
 
     /**
@@ -233,7 +238,7 @@ protected:
     void dropEvent(QDropEvent * event);
     bool event( QEvent* event );
     void closeEvent(QCloseEvent *event);
-    void showEvent(QShowEvent *event);
+
     /**
      * Generate a name for this view.
      */
@@ -245,10 +250,6 @@ public Q_SLOTS:
     void slotImageResolutionChanged();
     void slotImageSizeChanged(const QPointF &oldStillPoint, const QPointF &newStillPoint);
 
-private Q_SLOTS:
-
-    void setShown();
-
 private:
 
     class Private;
