@@ -31,9 +31,7 @@ class QPoint;
 class QRect;
 class QRectF;
 class QPainter;
-class KoViewConverter;
 class KisCoordinatesConverter;
-class KisViewManager;
 
 
 /**
@@ -63,7 +61,7 @@ public:
      */
     void paint(QPainter& gc, const QRectF& updateRect, const KisCoordinatesConverter *converter,KisCanvas2* canvas);
 
-public slots:
+public Q_SLOTS:
     /**
      * Set if the decoration is visible or not.
      */
