@@ -27,11 +27,8 @@
 #include <krita_export.h>
 
 class QRect;
-class QPainter;
 class QIcon;
 class QRect;
-class QDomDocument;
-class QDomElement;
 class QString;
 class KoShapeManager;
 class KoStore;
@@ -58,6 +55,14 @@ public:
 
     KisShapeLayer(KoShapeBasedDocumentBase* shapeController, KisImageWSP image, const QString &name, quint8 opacity);
     KisShapeLayer(const KisShapeLayer& _rhs);
+    /**
+     * Merge constructor.
+     *
+     * Creates a new layer as a merge of two existing layers.
+     *
+     * This is used by createMergedLayer()
+     */
+    KisShapeLayer(const KisShapeLayer& _merge, const KisShapeLayer &_addShapes);
     virtual ~KisShapeLayer();
 private:
     void initShapeLayer(KoShapeBasedDocumentBase* controller);
@@ -69,6 +74,8 @@ public:
 
 
     virtual void setImage(KisImageWSP image);
+
+    virtual KisLayerSP createMergedLayer(KisLayerSP prevLayer);
 public:
 
     // KoShape overrides
@@ -110,7 +117,7 @@ protected:
     friend class ShapeLayerContainerModel;
     KoViewConverter* converter() const;
 
-signals:
+Q_SIGNALS:
     /**
      * These signals are forwarded from the local shape manager
      * This is done because we switch KoShapeManager and therefore
@@ -122,7 +129,7 @@ signals:
     void selectionChanged();
     void currentLayerChanged(const KoShapeLayer *layer);
 
-signals:
+Q_SIGNALS:
     /**
      * A signal + slot to synchronize UI and image
      * threads. Image thread emits the signal, UI
@@ -130,7 +137,7 @@ signals:
      */
     void sigMoveShapes(const QPointF &diff);
 
-private slots:
+private Q_SLOTS:
     void slotMoveShapes(const QPointF &diff);
 
 private:
