@@ -126,19 +126,28 @@ void KisCanvasResourceProvider::setHDRGamma(float gamma)
 
 KoPattern * KisCanvasResourceProvider::currentPattern() const
 {
-    return static_cast<KoPattern*>(m_resourceManager->resource(CurrentPattern).value<void *>());
+    if (m_resourceManager->hasResource(CurrentPattern)) {
+        return m_resourceManager->resource(CurrentPattern).value<KoPattern*>();
+    }
+    else {
+        return 0;
+    }
 }
 
 KisFilterConfiguration * KisCanvasResourceProvider::currentGeneratorConfiguration() const
 {
-    return static_cast<KisFilterConfiguration*>(m_resourceManager->
-            resource(CurrentGeneratorConfiguration).value<void *>());
+    return m_resourceManager->resource(CurrentGeneratorConfiguration).value<KisFilterConfiguration*>();
 }
 
 
 KoAbstractGradient* KisCanvasResourceProvider::currentGradient() const
 {
-    return static_cast<KoAbstractGradient*>(m_resourceManager->resource(CurrentGradient).value<void *>());
+    if (m_resourceManager->hasResource(CurrentGradient)) {
+        return m_resourceManager->resource(CurrentGradient).value<KoAbstractGradient*>();
+    }
+    else {
+        return 0;
+    }
 }
 
 
@@ -205,12 +214,11 @@ void KisCanvasResourceProvider::setPreviousPaintOpPreset(const KisPaintOpPresetS
     m_resourceManager->setResource(PreviousPaintOpPreset, v);
 }
 
-
-
 void KisCanvasResourceProvider::slotPatternActivated(KoResource * res)
 {
-    KoPattern * pattern = dynamic_cast<KoPattern*>(res);
-    QVariant v = qVariantFromValue((void *) pattern);
+    KoPattern *pattern = dynamic_cast<KoPattern*>(res);
+    QVariant v;
+    v.setValue<KoPattern*>(pattern);
     m_resourceManager->setResource(CurrentPattern, v);
     emit sigPatternChanged(pattern);
 }
@@ -218,7 +226,8 @@ void KisCanvasResourceProvider::slotPatternActivated(KoResource * res)
 void KisCanvasResourceProvider::slotGeneratorConfigurationActivated(KisFilterConfiguration * res)
 {
     KisFilterConfiguration * generatorConfiguration = dynamic_cast<KisFilterConfiguration*>(res);
-    QVariant v = qVariantFromValue((void *) generatorConfiguration);
+    QVariant v;
+    v.setValue<KisFilterConfiguration*>(generatorConfiguration);
     m_resourceManager->setResource(CurrentGeneratorConfiguration, v);
 }
 
@@ -226,7 +235,8 @@ void KisCanvasResourceProvider::slotGradientActivated(KoResource *res)
 {
 
     KoAbstractGradient * gradient = dynamic_cast<KoAbstractGradient*>(res);
-    QVariant v = qVariantFromValue((void *) gradient);
+    QVariant v;
+    v.setValue<KoAbstractGradient*>(gradient);
     m_resourceManager->setResource(CurrentGradient, v);
     emit sigGradientChanged(gradient);
 }
