@@ -65,7 +65,9 @@
 #include "kis_config.h"
 
 #include "widgets/kis_popup_button.h"
+#include "widgets/kis_tool_options_popup.h"
 #include "widgets/kis_paintop_presets_popup.h"
+#include "widgets/kis_tool_options_popup.h"
 #include "widgets/kis_paintop_presets_chooser_popup.h"
 #include "widgets/kis_workspace_chooser.h"
 #include "widgets/kis_paintop_list_widget.h"
@@ -84,9 +86,10 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
     : QWidget(parent)
     , m_resourceProvider(view->resourceProvider())
     , m_optionWidget(0)
-    , m_settingsWidget(0)
-    , m_presetWidget(0)
-    , m_brushChooser(0)
+    , m_toolOptionsPopupButton(0)
+    , m_brushEditorPopupButton(0)
+    , m_presetSelectorPopupButton(0)
+    , m_toolOptionsPopup(0)
     , m_viewManager(view)
     , m_previousNode(0)
     , m_currTabletToolID(KoInputDevice::invalid())
@@ -108,18 +111,28 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
 
     setWindowTitle(i18n("Painter's Toolchest"));
 
-    m_settingsWidget = new KisPopupButton(this);
-    m_settingsWidget->setIcon(koIcon("paintop_settings_02"));
-    m_settingsWidget->setToolTip(i18n("Edit brush settings"));
-    m_settingsWidget->setFixedSize(32, 32);
+    KConfigGroup grp = KGlobal::config()->group("krita").group("Toolbar BrushesAndStuff");
+    int iconsize = grp.readEntry("IconSize", 32);
 
-    m_presetWidget = new KisPopupButton(this);
-    m_presetWidget->setIcon(koIcon("paintop_settings_01"));
-    m_presetWidget->setToolTip(i18n("Choose brush preset"));
-    m_presetWidget->setFixedSize(32, 32);
+    if (!cfg.toolOptionsInDocker()) {
+        m_toolOptionsPopupButton = new KisPopupButton(this);
+        m_toolOptionsPopupButton->setIcon(koIcon("configure"));
+        m_toolOptionsPopupButton->setToolTip(i18n("Tool Settings"));
+        m_toolOptionsPopupButton->setFixedSize(iconsize, iconsize);
+    }
+
+    m_brushEditorPopupButton = new KisPopupButton(this);
+    m_brushEditorPopupButton->setIcon(koIcon("paintop_settings_02"));
+    m_brushEditorPopupButton->setToolTip(i18n("Edit brush settings"));
+    m_brushEditorPopupButton->setFixedSize(iconsize, iconsize);
+
+    m_presetSelectorPopupButton = new KisPopupButton(this);
+    m_presetSelectorPopupButton->setIcon(koIcon("paintop_settings_01"));
+    m_presetSelectorPopupButton->setToolTip(i18n("Choose brush preset"));
+    m_presetSelectorPopupButton->setFixedSize(iconsize, iconsize);
 
     m_eraseModeButton = new QToolButton(this);
-    m_eraseModeButton->setFixedSize(32, 32);
+    m_eraseModeButton->setFixedSize(iconsize, iconsize);
     m_eraseModeButton->setCheckable(true);
 
     KisAction* eraseAction = new KisAction(i18n("Set eraser mode"), m_eraseModeButton);
@@ -133,7 +146,7 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
     eraserBrushSize = 0; // brush size changed when using erase mode
 
     m_reloadButton = new QToolButton(this);
-    m_reloadButton->setFixedSize(32, 32);
+    m_reloadButton->setFixedSize(iconsize, iconsize);
     m_reloadButton->setCheckable(true);
 
     KisAction* reloadAction = new KisAction(i18n("Reload Original Preset"), m_reloadButton);
@@ -142,9 +155,8 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
     m_reloadButton->setDefaultAction(reloadAction);
     m_viewManager->actionCollection()->addAction("reload_preset_action", reloadAction);
 
-
     m_alphaLockButton = new QToolButton(this);
-    m_alphaLockButton->setFixedSize(32, 32);
+    m_alphaLockButton->setFixedSize(iconsize, iconsize);
     m_alphaLockButton->setCheckable(true);
     KisAction* alphaLockAction = new KisAction(i18n("Preserve Alpha"), m_alphaLockButton);
     alphaLockAction->setActivationFlags(KisAction::ACTIVE_DEVICE);
@@ -153,26 +165,26 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
     m_alphaLockButton->setDefaultAction(alphaLockAction);
     m_viewManager->actionCollection()->addAction("preserve_alpha", alphaLockAction);
 
-    hMirrorButton = new QToolButton(this);
-    hMirrorButton->setFixedSize(32, 32);
-    hMirrorButton->setCheckable(true);
+    m_hMirrorButton = new QToolButton(this);
+    m_hMirrorButton->setFixedSize(iconsize, iconsize);
+    m_hMirrorButton->setCheckable(true);
 
-    m_hMirrorAction = new KisAction(i18n("Set horizontal mirror mode"), hMirrorButton);
+    m_hMirrorAction = new KisAction(i18n("Set horizontal mirror mode"), m_hMirrorButton);
     m_hMirrorAction->setIcon(themedIcon("symmetry-horizontal"));
     m_hMirrorAction->setActivationFlags(KisAction::ACTIVE_DEVICE);
     m_hMirrorAction->setCheckable(true);
-    hMirrorButton->setDefaultAction(m_hMirrorAction);
+    m_hMirrorButton->setDefaultAction(m_hMirrorAction);
     m_viewManager->actionCollection()->addAction("hmirror_action", m_hMirrorAction);
 
-    vMirrorButton = new QToolButton(this);
-    vMirrorButton->setFixedSize(32, 32);
-    vMirrorButton->setCheckable(true);
+    m_vMirrorButton = new QToolButton(this);
+    m_vMirrorButton->setFixedSize(iconsize, iconsize);
+    m_vMirrorButton->setCheckable(true);
 
-    m_vMirrorAction = new KisAction(i18n("Set vertical mirror mode"), vMirrorButton);
+    m_vMirrorAction = new KisAction(i18n("Set vertical mirror mode"), m_vMirrorButton);
     m_vMirrorAction->setActivationFlags(KisAction::ACTIVE_DEVICE);
     m_vMirrorAction->setIcon(themedIcon("symmetry-vertical"));
     m_vMirrorAction->setCheckable(true);
-    vMirrorButton->setDefaultAction(m_vMirrorAction);
+    m_vMirrorButton->setDefaultAction(m_vMirrorAction);
     m_viewManager->actionCollection()->addAction("vmirror_action", m_vMirrorAction);
 
     const bool sliderLabels = cfg.sliderLabels();
@@ -208,13 +220,15 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
         slOpacity->setValue(1.0);
         slOpacity->setSingleStep(0.05);
         slOpacity->setMinimumWidth(qMax(sliderWidth, slOpacity->sizeHint().width()));
-        slOpacity->setFixedHeight(32);
+        slOpacity->setFixedHeight(iconsize);
+        slOpacity->setBlockUpdateSignalOnDrag(true);
 
         slFlow->setRange(0.0, 1.0, 2);
         slFlow->setValue(1.0);
         slFlow->setSingleStep(0.05);
         slFlow->setMinimumWidth(qMax(sliderWidth, slFlow->sizeHint().width()));
-        slFlow->setFixedHeight(32);
+        slFlow->setFixedHeight(iconsize);
+        slFlow->setBlockUpdateSignalOnDrag(true);
 
         slSize->setRange(0, 1000, 2);
         slSize->setValue(100);
@@ -223,13 +237,14 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
         slSize->setExponentRatio(3.0);
         slSize->setSuffix(" px");
         slSize->setMinimumWidth(qMax(sliderWidth, slSize->sizeHint().width()));
-        slSize->setFixedHeight(32);
+        slSize->setFixedHeight(iconsize);
+        slSize->setBlockUpdateSignalOnDrag(true);
 
         m_sliderChooser[i]->chooseWidget(cfg.toolbarSlider(i + 1));
     }
 
     m_cmbCompositeOp = new KisCompositeOpComboBox();
-    m_cmbCompositeOp->setFixedHeight(32);
+    m_cmbCompositeOp->setFixedHeight(iconsize);
     foreach(KAction * a, m_cmbCompositeOp->blendmodeActions()) {
         m_viewManager->actionCollection()->addAction(a->text(), a);
     }
@@ -237,7 +252,7 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
     m_workspaceWidget = new KisPopupButton(this);
     m_workspaceWidget->setIcon(koIcon("workspace-chooser"));
     m_workspaceWidget->setToolTip(i18n("Choose workspace"));
-    m_workspaceWidget->setFixedSize(32, 32);
+    m_workspaceWidget->setFixedSize(iconsize, iconsize);
     m_workspaceWidget->setPopupWidget(new KisWorkspaceChooser(view));
 
     QHBoxLayout* baseLayout = new QHBoxLayout(this);
@@ -247,8 +262,11 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
     baseLayout->setContentsMargins(0, 0, 0, 0);
 
     m_layout = new QHBoxLayout(m_paintopWidget);
-    m_layout->addWidget(m_settingsWidget);
-    m_layout->addWidget(m_presetWidget);
+    if (!cfg.toolOptionsInDocker()) {
+        m_layout->addWidget(m_toolOptionsPopupButton);
+    }
+    m_layout->addWidget(m_brushEditorPopupButton);
+    m_layout->addWidget(m_presetSelectorPopupButton);
     m_layout->setSpacing(4);
     m_layout->setContentsMargins(0, 0, 0, 0);
 
@@ -299,10 +317,27 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
     action->setShortcut(KShortcut(Qt::Key_Slash));
     connect(action, SIGNAL(triggered()), this, SLOT(slotSwitchToPreviousPreset()));
 
+    if (!cfg.toolOptionsInDocker()) {
+        action = new KAction(i18n("Show Tool Options"), this);
+        view->actionCollection()->addAction("show_tool_options", action);
+        action->setShortcut(Qt::Key_Backslash);
+        connect(action, SIGNAL(triggered()), m_toolOptionsPopupButton, SLOT(showPopupWidget()));
+    }
+
+    action = new KAction(i18n("Show Brush Editor"), this);
+    view->actionCollection()->addAction("show_brush_editor", action);
+    action->setShortcut(Qt::Key_F5);
+    connect(action, SIGNAL(triggered()), m_brushEditorPopupButton, SLOT(showPopupWidget()));
+
+    action = new KAction(i18n("Show Brush Presets"), this);
+    view->actionCollection()->addAction("show_brush_presets", action);
+    action->setShortcut(Qt::Key_F6);
+    connect(action, SIGNAL(triggered()), m_presetSelectorPopupButton, SLOT(showPopupWidget()));
+
     QWidget* mirrorActions = new QWidget(this);
     QHBoxLayout* mirrorLayout = new QHBoxLayout(mirrorActions);
-    mirrorLayout->addWidget(hMirrorButton);
-    mirrorLayout->addWidget(vMirrorButton);
+    mirrorLayout->addWidget(m_hMirrorButton);
+    mirrorLayout->addWidget(m_vMirrorButton);
     mirrorLayout->setSpacing(4);
     mirrorLayout->setContentsMargins(0, 0, 0, 0);
     action = new KAction(i18n("Mirror"), this);
@@ -313,13 +348,19 @@ KisPaintopBox::KisPaintopBox(KisViewManager *view, QWidget *parent, const char *
     view->actionCollection()->addAction("workspaces", action);
     action->setDefaultWidget(m_workspaceWidget);
 
+    if (!cfg.toolOptionsInDocker()) {
+        m_toolOptionsPopup = new KisToolOptionsPopup();
+        m_toolOptionsPopupButton->setPopupWidget(m_toolOptionsPopup);
+        m_toolOptionsPopup->switchDetached(false);
+    }
+
     m_presetsPopup = new KisPaintOpPresetsPopup(m_resourceProvider);
-    m_settingsWidget->setPopupWidget(m_presetsPopup);
+    m_brushEditorPopupButton->setPopupWidget(m_presetsPopup);
     m_presetsPopup->switchDetached(false);
 
     m_presetsChooserPopup = new KisPaintOpPresetsChooserPopup();
     m_presetsChooserPopup->setFixedSize(500, 600);
-    m_presetWidget->setPopupWidget(m_presetsChooserPopup);
+    m_presetSelectorPopupButton->setPopupWidget(m_presetsChooserPopup);
 
     m_prevCompositeOpID = KoCompositeOpRegistry::instance().getDefaultCompositeOp().id();
     m_currCompositeOpID = KoCompositeOpRegistry::instance().getDefaultCompositeOp().id();
@@ -414,6 +455,13 @@ void KisPaintopBox::restoreResource(KoResource* resource)
     }
 }
 
+void KisPaintopBox::newOptionWidgets(const QList<QPointer<QWidget> > &optionWidgetList)
+{
+    if (m_toolOptionsPopup) {
+        m_toolOptionsPopup->newOptionWidgets(optionWidgetList);
+    }
+}
+
 void KisPaintopBox::resourceSelected(KoResource* resource)
 {
     KisPaintOpPreset* preset = dynamic_cast<KisPaintOpPreset*>(resource);
@@ -488,7 +536,7 @@ void KisPaintopBox::setCurrentPaintop(const KoID& paintop, KisPaintOpPresetSP pr
 
     m_presetsPopup->setPaintOpSettingsWidget(m_optionWidget);
 
-    Q_ASSERT(m_optionWidget && m_presetWidget);
+    Q_ASSERT(m_optionWidget && m_presetSelectorPopupButton);
     connect(m_optionWidget, SIGNAL(sigConfigurationUpdated()), this, SLOT(slotUpdatePreset()));
     connect(m_optionWidget, SIGNAL(sigSaveLockedConfig(KisPropertiesConfiguration*)), this, SLOT(slotSaveLockedOptionToPreset(KisPropertiesConfiguration*)));
     connect(m_optionWidget, SIGNAL(sigDropLockedConfig(KisPropertiesConfiguration*)), this, SLOT(slotDropLockedOption(KisPropertiesConfiguration*)));
@@ -498,7 +546,7 @@ void KisPaintopBox::setCurrentPaintop(const KoID& paintop, KisPaintOpPresetSP pr
     KisPaintOpFactory* paintOp = KisPaintOpRegistry::instance()->get(paintop.id());
     QString pixFilename = KisFactory::componentData().dirs()->findResource("kis_images", paintOp->pixmap());
 
-    m_settingsWidget->setIcon(QIcon(pixFilename));
+    m_brushEditorPopupButton->setIcon(QIcon(pixFilename));
     m_resourceProvider->setPaintOpPreset(preset);
     m_presetsPopup->setCurrentPaintOp(paintop.id());
 
@@ -588,8 +636,8 @@ void KisPaintopBox::setWidgetState(int flags)
     }
 
     if (flags & (ENABLE_PRESETS | DISABLE_PRESETS)) {
-        m_presetWidget->setEnabled(flags & ENABLE_PRESETS);
-        m_settingsWidget->setEnabled(flags & ENABLE_PRESETS);
+        m_presetSelectorPopupButton->setEnabled(flags & ENABLE_PRESETS);
+        m_brushEditorPopupButton->setEnabled(flags & ENABLE_PRESETS);
     }
 
     for (int i = 0; i < 3; ++i) {
@@ -842,13 +890,13 @@ void KisPaintopBox::slotSetCompositeMode(int index)
 void KisPaintopBox::slotHorizontalMirrorChanged(bool value)
 {
     m_resourceProvider->setMirrorHorizontal(value);
-    toggleHighlightedButton(hMirrorButton);
+    toggleHighlightedButton(m_hMirrorButton);
 }
 
 void KisPaintopBox::slotVerticalMirrorChanged(bool value)
 {
     m_resourceProvider->setMirrorVertical(value);
-    toggleHighlightedButton(vMirrorButton);
+    toggleHighlightedButton(m_vMirrorButton);
 }
 
 void KisPaintopBox::sliderChanged(int n)
