@@ -23,27 +23,19 @@
 #ifndef KIS_RESOURCESERVERPROVIDER_H_
 #define KIS_RESOURCESERVERPROVIDER_H_
 
-#include <QString>
-#include <QStringList>
-#include <QList>
-
-#include <KoResource.h>
 #include <KoResourceServer.h>
-#include <KoResourceServerProvider.h>
 #include <KoResourceServerAdapter.h>
 
 #include <kis_paintop_preset.h>
 
 #include <krita_export.h>
 
-class KoResource;
 class KoResourceLoaderThread;
-class KisPaintOpPreset;
 class KisWorkspaceResource;
 class KisPSDLayerStyleCollectionResource;
 
-typedef KoResourceServerSimpleConstruction<KisPaintOpPreset, SharedPointerStroragePolicy<KisPaintOpPresetSP> > KisPaintOpPresetResourceServer;
-typedef KoResourceServerAdapter<KisPaintOpPreset, SharedPointerStroragePolicy<KisPaintOpPresetSP> > KisPaintOpPresetResourceServerAdapter;
+typedef KoResourceServerSimpleConstruction<KisPaintOpPreset, SharedPointerStoragePolicy<KisPaintOpPresetSP> > KisPaintOpPresetResourceServer;
+typedef KoResourceServerAdapter<KisPaintOpPreset, SharedPointerStoragePolicy<KisPaintOpPresetSP> > KisPaintOpPresetResourceServerAdapter;
 
 class KRITAUI_EXPORT KisResourceServerProvider : public QObject
 {
