@@ -83,6 +83,8 @@ class  KRITAUI_EXPORT KisTool
 {
     Q_OBJECT
 
+    Q_PROPERTY(bool isActive READ isActive NOTIFY isActiveChanged)
+
 public:
     enum { FLAG_USES_CUSTOM_PRESET=0x01, FLAG_USES_CUSTOM_COMPOSITEOP=0x02 };
 
@@ -198,6 +200,8 @@ public:
     void mouseReleaseEvent(KoPointerEvent *event);
     void mouseMoveEvent(KoPointerEvent *event);
 
+    bool isActive() const;
+
 public Q_SLOTS:
     virtual void activate(ToolActivation toolActivation, const QSet<KoShape*> &shapes);
     virtual void deactivate();
@@ -208,6 +212,9 @@ public Q_SLOTS:
     // this will likely be expanded.
     virtual void updateSettingsViews();
 
+Q_SIGNALS:
+    void isActiveChanged();
+
 protected:
     // conversion methods are also needed by the paint information builder
     friend class KisToolPaintingInformationBuilder;
@@ -254,6 +261,17 @@ protected:
 
     virtual QWidget* createOptionWidget();
 
+    /**
+     * To determine whether this tool will change its behavior when
+     * modifier keys are pressed
+     */
+    virtual bool listeningToModifiers();
+    /**
+     * Request that this tool no longer listen to modifier keys
+     * (Responding to the request is optional)
+     */
+    virtual void listenToModifiers(bool listen);
+
 protected:
     KisImageWSP image() const;
     QCursor cursor() const;
@@ -285,6 +303,9 @@ protected:
     /// Checks checks if the selection is editable, only applies to local selection as global selection is always editable
     bool selectionEditable();
 
+    /// Override the cursor appropriately if current node is not editable
+    bool overrideCursorIfNotEditable();
+
 protected:
     enum ToolMode {
         HOVER_MODE,
@@ -299,7 +320,6 @@ protected:
     virtual void setMode(ToolMode mode);
     virtual ToolMode mode() const;
 
-
 protected Q_SLOTS:
     /**
      * Called whenever the configuration settings change.
@@ -337,6 +357,7 @@ private Q_SLOTS:
 
 private:
     ToolMode m_mode;
+    bool m_isActive;
 
     struct Private;
     Private* const d;
@@ -345,4 +366,3 @@ private:
 
 
 #endif // KIS_TOOL_H_
-
