@@ -151,28 +151,37 @@ KoStyleManager::KoStyleManager(QObject *parent)
         d->defaultBibEntriesStyleId.append(style->styleId());
     }
 
+    d->footNotesConfiguration = new KoOdfNotesConfiguration(KoOdfNotesConfiguration::Footnote);
+    d->endNotesConfiguration = new KoOdfNotesConfiguration(KoOdfNotesConfiguration::Endnote);
+
     KoParagraphStyle *style = new KoParagraphStyle();
     style->setName("Footnote");
     setParent(d->defaultParagraphStyle);
     add(style);
+    d->footNotesConfiguration->setDefaultNoteParagraphStyle(style);
     style = new KoParagraphStyle();
     style->setName("Endnote");
     setParent(d->defaultParagraphStyle);
     add(style);
+    d->endNotesConfiguration->setDefaultNoteParagraphStyle(style);
     KoCharacterStyle *cStyle = new KoCharacterStyle();
     cStyle->setName("Footnote anchor");
     cStyle->setVerticalAlignment(QTextCharFormat::AlignSuperScript);
     add(cStyle);
+    d->footNotesConfiguration->setCitationBodyTextStyle(cStyle);
     cStyle = new KoCharacterStyle();
     cStyle->setName("Footnote Symbol");
     add(cStyle);
+    d->footNotesConfiguration->setCitationTextStyle(cStyle);
     cStyle = new KoCharacterStyle();
     cStyle->setName("Endnote anchor");
     cStyle->setVerticalAlignment(QTextCharFormat::AlignSuperScript);
     add(cStyle);
+    d->endNotesConfiguration->setCitationBodyTextStyle(cStyle);
     cStyle = new KoCharacterStyle();
     cStyle->setName("Endnote Symbol");
     add(cStyle);
+    d->endNotesConfiguration->setCitationTextStyle(cStyle);
 
     d->footNotesConfiguration = 0;
     d->endNotesConfiguration = 0;
@@ -946,14 +955,8 @@ KoSectionStyle *KoStyleManager::sectionStyle(const QString &name) const
 KoOdfNotesConfiguration *KoStyleManager::notesConfiguration(KoOdfNotesConfiguration::NoteClass noteClass) const
 {
     if (noteClass == KoOdfNotesConfiguration::Endnote) {
-        if (!d->endNotesConfiguration) {
-            d->endNotesConfiguration = new KoOdfNotesConfiguration(noteClass);
-        }
         return d->endNotesConfiguration;
     } else if (noteClass == KoOdfNotesConfiguration::Footnote) {
-        if (!d->footNotesConfiguration) {
-            d->footNotesConfiguration = new KoOdfNotesConfiguration(noteClass);
-        }
         return d->footNotesConfiguration;
     } else {
         return 0;
