@@ -46,6 +46,9 @@ public:
     virtual bool save();
     virtual bool saveToDevice(QIODevice* dev) const;
 
+    bool loadPatFromDevice(QIODevice *dev);
+    bool savePatToDevice(QIODevice* dev) const;
+
     qint32 width() const;
     qint32 height() const;
 
