@@ -263,6 +263,8 @@ public:
     explicit KoSegmentGradient(const QString &file);
     virtual ~KoSegmentGradient();
 
+    KoAbstractGradient* clone() const;
+
     /// reimplemented
     virtual bool load();
     virtual bool loadFromDevice(QIODevice *dev);
@@ -399,8 +401,13 @@ public:
      * @return true if it's possible to remove an segment
      */
     bool removeSegmentPossible() const;
+
+    const QList<KoGradientSegment *>& segments() const;
+
 protected:
 
+    KoSegmentGradient(const KoSegmentGradient &rhs);
+
     virtual QByteArray generateMD5() const;
 
     inline void pushSegment(KoGradientSegment* segment) {
