@@ -78,10 +78,10 @@ public:
         , updatesBlocked(false)
         , savedResourceWhileReset(0)
     {}
-    KoResourceModel* model;
-    KoResourceTaggingManager* tagManager;
-    KoResourceItemView* view;
-    QButtonGroup* buttonGroup;
+    KoResourceModel *model;
+    KoResourceTaggingManager *tagManager;
+    KoResourceItemView *view;
+    QButtonGroup *buttonGroup;
     QToolButton  *viewModeButton;
 
     QString knsrcFile;
@@ -99,28 +99,27 @@ public:
 };
 
 KoResourceItemChooser::KoResourceItemChooser(QSharedPointer<KoAbstractResourceServerAdapter> resourceAdapter, QWidget *parent, bool usePreview)
-    : QWidget( parent )
-    , d( new Private() )
+    : QWidget(parent)
+    , d(new Private())
 {
     Q_ASSERT(resourceAdapter);
 
     d->splitter = new QSplitter(this);
 
     d->model = new KoResourceModel(resourceAdapter, this);
-    connect(d->model, SIGNAL(beforeResourcesLayoutReset(KoResource*)), SLOT(slotBeforeResourcesLayoutReset(KoResource*)));
+    connect(d->model, SIGNAL(beforeResourcesLayoutReset(KoResource *)), SLOT(slotBeforeResourcesLayoutReset(KoResource *)));
     connect(d->model, SIGNAL(afterResourcesLayoutReset()), SLOT(slotAfterResourcesLayoutReset()));
 
     d->view = new KoResourceItemView(this);
     d->view->setModel(d->model);
-    d->view->setItemDelegate( new KoResourceItemDelegate( this ) );
-    d->view->setSelectionMode( QAbstractItemView::SingleSelection );
+    d->view->setItemDelegate(new KoResourceItemDelegate(this));
+    d->view->setSelectionMode(QAbstractItemView::SingleSelection);
     d->view->viewport()->installEventFilter(this);
 
     connect(d->view, SIGNAL(currentResourceChanged(QModelIndex)), this, SLOT(activated(QModelIndex)));
-    connect(d->view, SIGNAL(clicked(QModelIndex)), this, SLOT(activated(QModelIndex)));
-    connect (d->view, SIGNAL(contextMenuRequested(QPoint)), this, SLOT(contextMenuRequested(QPoint)));
+    connect(d->view, SIGNAL(contextMenuRequested(QPoint)), this, SLOT(contextMenuRequested(QPoint)));
 
-    connect (d->view, SIGNAL(sigSizeChanged()), this, SLOT(updateView()));
+    connect(d->view, SIGNAL(sigSizeChanged()), this, SLOT(updateView()));
 
     d->splitter->addWidget(d->view);
     d->splitter->setStretchFactor(0, 2);
@@ -142,14 +141,14 @@ KoResourceItemChooser::KoResourceItemChooser(QSharedPointer<KoAbstractResourceSe
     }
 
     d->splitter->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
-    connect(d->splitter, SIGNAL(splitterMoved(int,int)), SIGNAL(splitterMoved()));
+    connect(d->splitter, SIGNAL(splitterMoved(int, int)), SIGNAL(splitterMoved()));
 
     d->buttonGroup = new QButtonGroup(this);
     d->buttonGroup->setExclusive(false);
 
-    QGridLayout* layout = new QGridLayout(this);
+    QGridLayout *layout = new QGridLayout(this);
 
-    QGridLayout* buttonLayout = new QGridLayout;
+    QGridLayout *buttonLayout = new QGridLayout;
 
     QPushButton *button = new QPushButton(this);
     button->setIcon(koIcon("document-open"));
@@ -178,10 +177,10 @@ KoResourceItemChooser::KoResourceItemChooser(QSharedPointer<KoAbstractResourceSe
     button->setToolTip(i18nc("@info:tooltip", "Share Resource"));
     button->setEnabled(false);
     button->hide();
-    d->buttonGroup->addButton( button, Button_GhnsUpload);
+    d->buttonGroup->addButton(button, Button_GhnsUpload);
     buttonLayout->addWidget(button, 0, 4);
 
-    connect( d->buttonGroup, SIGNAL(buttonClicked(int)), this, SLOT(slotButtonClicked(int)));
+    connect(d->buttonGroup, SIGNAL(buttonClicked(int)), this, SLOT(slotButtonClicked(int)));
 
     buttonLayout->setColumnStretch(0, 1);
     buttonLayout->setColumnStretch(1, 1);
@@ -214,12 +213,12 @@ KoResourceItemChooser::~KoResourceItemChooser()
     delete d;
 }
 
-void KoResourceItemChooser::slotButtonClicked( int button )
+void KoResourceItemChooser::slotButtonClicked(int button)
 {
-    if (button == Button_Import ) {
+    if (button == Button_Import) {
         QString extensions = d->model->extensions();
         QString filter = QString("%1")
-                .arg(extensions.replace(QString(":"), QString(" ")));
+                         .arg(extensions.replace(QString(":"), QString(" ")));
 
 
         KoFileDialog dialog(0, KoFileDialog::OpenFile, "OpenDocument");
@@ -228,15 +227,14 @@ void KoResourceItemChooser::slotButtonClicked( int button )
         QString filename = dialog.url();
 
         d->model->importResourceFile(filename);
-    }
-    else if( button == Button_Remove ) {
+    } else if (button == Button_Remove) {
         QModelIndex index = d->view->currentIndex();
         int row = index.row();
         int column = index.column();
-        if( index.isValid() ) {
+        if (index.isValid()) {
 
-            KoResource * resource = resourceFromModelIndex(index);
-            if( resource ) {
+            KoResource *resource = resourceFromModelIndex(index);
+            if (resource) {
                 d->model->removeResource(resource);
             }
         }
@@ -255,27 +253,26 @@ void KoResourceItemChooser::slotButtonClicked( int button )
         KNS3::DownloadDialog dialog(d->knsrcFile, this);
         dialog.exec();
 
-        foreach (const KNS3::Entry& e, dialog.changedEntries()) {
+        foreach (const KNS3::Entry & e, dialog.changedEntries()) {
 
-            foreach(const QString &file, e.installedFiles()) {
+            foreach (const QString & file, e.installedFiles()) {
                 QFileInfo fi(file);
-                d->model->importResourceFile( fi.absolutePath()+'/'+fi.fileName() , false );
+                d->model->importResourceFile(fi.absolutePath() + '/' + fi.fileName() , false);
             }
 
-            foreach(const QString &file, e.uninstalledFiles()) {
+            foreach (const QString & file, e.uninstalledFiles()) {
                 QFileInfo fi(file);
-                d->model->removeResourceFile(fi.absolutePath()+'/'+fi.fileName());
+                d->model->removeResourceFile(fi.absolutePath() + '/' + fi.fileName());
             }
         }
-    }
-    else if (button == Button_GhnsUpload) {
+    } else if (button == Button_GhnsUpload) {
 
         QModelIndex index = d->view->currentIndex();
-        if( index.isValid() ) {
+        if (index.isValid()) {
 
 
-            KoResource * resource = resourceFromModelIndex(index);
-            if( resource ) {
+            KoResource *resource = resourceFromModelIndex(index);
+            if (resource) {
                 KNS3::UploadDialog dialog(d->knsrcFile, this);
                 dialog.setUploadFile(KUrl::fromLocalFile(resource->filename()));
                 dialog.setUploadName(resource->name());
@@ -287,13 +284,14 @@ void KoResourceItemChooser::slotButtonClicked( int button )
     updateButtonState();
 }
 
-void KoResourceItemChooser::showButtons( bool show )
+void KoResourceItemChooser::showButtons(bool show)
 {
-    foreach( QAbstractButton * button, d->buttonGroup->buttons() )
+    foreach (QAbstractButton * button, d->buttonGroup->buttons()) {
         show ? button->show() : button->hide();
+    }
 }
 
-void KoResourceItemChooser::showGetHotNewStuff( bool showDownload, bool showUpload )
+void KoResourceItemChooser::showGetHotNewStuff(bool showDownload, bool showUpload)
 {
 #ifdef GHNS
 
@@ -318,10 +316,10 @@ void KoResourceItemChooser::showTaggingBar(bool show)
 
 }
 
-void KoResourceItemChooser::setRowCount( int rowCount )
+void KoResourceItemChooser::setRowCount(int rowCount)
 {
     int resourceCount = d->model->resourcesCount();
-    d->model->setColumnCount( static_cast<qreal>(resourceCount) / rowCount );
+    d->model->setColumnCount(static_cast<qreal>(resourceCount) / rowCount);
     //Force an update to get the right row height (in theory)
     QRect geometry = d->view->geometry();
     d->view->setViewMode(KoResourceItemView::FIXED_ROWS);
@@ -329,27 +327,27 @@ void KoResourceItemChooser::setRowCount( int rowCount )
     d->view->setGeometry(geometry);
 }
 
-void KoResourceItemChooser::setColumnCount( int columnCount )
+void KoResourceItemChooser::setColumnCount(int columnCount)
 {
-    d->model->setColumnCount( columnCount );
+    d->model->setColumnCount(columnCount);
 }
 
-void KoResourceItemChooser::setRowHeight( int rowHeight )
+void KoResourceItemChooser::setRowHeight(int rowHeight)
 {
-    d->view->verticalHeader()->setDefaultSectionSize( rowHeight );
+    d->view->verticalHeader()->setDefaultSectionSize(rowHeight);
 }
 
-void KoResourceItemChooser::setColumnWidth( int columnWidth )
+void KoResourceItemChooser::setColumnWidth(int columnWidth)
 {
-    d->view->horizontalHeader()->setDefaultSectionSize( columnWidth );
+    d->view->horizontalHeader()->setDefaultSectionSize(columnWidth);
 }
 
-void KoResourceItemChooser::setItemDelegate( QAbstractItemDelegate * delegate )
+void KoResourceItemChooser::setItemDelegate(QAbstractItemDelegate *delegate)
 {
     d->view->setItemDelegate(delegate);
 }
 
-KoResource *  KoResourceItemChooser::currentResource() const
+KoResource *KoResourceItemChooser::currentResource() const
 {
     QModelIndex index = d->view->currentIndex();
     if (index.isValid()) {
@@ -358,7 +356,7 @@ KoResource *  KoResourceItemChooser::currentResource() const
     return 0;
 }
 
-void KoResourceItemChooser::setCurrentResource(KoResource* resource)
+void KoResourceItemChooser::setCurrentResource(KoResource *resource)
 {
     // don't update if the change came from the same chooser
     if (d->updatesBlocked) {
@@ -366,7 +364,7 @@ void KoResourceItemChooser::setCurrentResource(KoResource* resource)
     }
 
     QModelIndex index = d->model->indexFromResource(resource);
-    if( !index.isValid() )
+    if (!index.isValid())
         return;
 
     d->view->setCurrentIndex(index);
@@ -405,7 +403,7 @@ void KoResourceItemChooser::setGrayscalePreview(bool grayscale)
 void KoResourceItemChooser::setCurrentItem(int row, int column)
 {
     QModelIndex index = d->model->index(row, column);
-    if( !index.isValid() )
+    if (!index.isValid())
         return;
 
     d->view->setCurrentIndex(index);
@@ -414,7 +412,7 @@ void KoResourceItemChooser::setCurrentItem(int row, int column)
     }
 }
 
-void KoResourceItemChooser::setProxyModel( QAbstractProxyModel* proxyModel )
+void KoResourceItemChooser::setProxyModel(QAbstractProxyModel *proxyModel)
 {
     proxyModel->setSourceModel(d->model);
     d->view->setModel(proxyModel);
@@ -422,10 +420,10 @@ void KoResourceItemChooser::setProxyModel( QAbstractProxyModel* proxyModel )
 
 void KoResourceItemChooser::activated(const QModelIndex &/*index*/)
 {
-    KoResource* resource = currentResource();
+    KoResource *resource = currentResource();
     if (resource) {
         d->updatesBlocked = true;
-        emit resourceSelected( resource );
+        emit resourceSelected(resource);
         d->updatesBlocked = false;
 
         updatePreview(resource);
@@ -435,22 +433,22 @@ void KoResourceItemChooser::activated(const QModelIndex &/*index*/)
 
 void KoResourceItemChooser::updateButtonState()
 {
-    QAbstractButton * removeButton = d->buttonGroup->button( Button_Remove );
-    if( ! removeButton )
+    QAbstractButton *removeButton = d->buttonGroup->button(Button_Remove);
+    if (! removeButton)
         return;
 
-    QAbstractButton * uploadButton = d->buttonGroup->button(Button_GhnsUpload);
-    if(!uploadButton)
+    QAbstractButton *uploadButton = d->buttonGroup->button(Button_GhnsUpload);
+    if (!uploadButton)
         return;
 
-    KoResource * resource = currentResource();
-    if( resource ) {
-        removeButton->setEnabled( true );
+    KoResource *resource = currentResource();
+    if (resource) {
+        removeButton->setEnabled(true);
         uploadButton->setEnabled(resource->removable());
         return;
     }
 
-    removeButton->setEnabled( false );
+    removeButton->setEnabled(false);
     uploadButton->setEnabled(false);
 }
 
@@ -460,9 +458,9 @@ void KoResourceItemChooser::updatePreview(KoResource *resource)
 
     QImage image = resource->image();
 
-    if (image.format()!= QImage::Format_RGB32 ||
-            image.format() != QImage::Format_ARGB32 ||
-            image.format() != QImage::Format_ARGB32_Premultiplied) {
+    if (image.format() != QImage::Format_RGB32 ||
+        image.format() != QImage::Format_ARGB32 ||
+        image.format() != QImage::Format_ARGB32_Premultiplied) {
 
         image = image.convertToFormat(QImage::Format_ARGB32_Premultiplied);
     }
@@ -482,9 +480,9 @@ void KoResourceItemChooser::updatePreview(KoResource *resource)
     // Only convert to grayscale if it is rgb. Otherwise, it's gray already.
     if (d->grayscalePreview && !image.isGrayscale()) {
 
-        QRgb* pixel = reinterpret_cast<QRgb*>( image.bits() );
-        for (int row = 0; row < image.height(); ++row ) {
-            for (int col = 0; col < image.width(); ++col ){
+        QRgb *pixel = reinterpret_cast<QRgb *>(image.bits());
+        for (int row = 0; row < image.height(); ++row) {
+            for (int col = 0; col < image.width(); ++col) {
                 const QRgb currentPixel = pixel[row * image.width() + col];
                 const int red = qRed(currentPixel);
                 const int green = qGreen(currentPixel);
@@ -498,22 +496,22 @@ void KoResourceItemChooser::updatePreview(KoResource *resource)
 
 }
 
-KoResource* KoResourceItemChooser::resourceFromModelIndex(const QModelIndex& index) const
+KoResource *KoResourceItemChooser::resourceFromModelIndex(const QModelIndex &index) const
 {
-    if(!index.isValid())
+    if (!index.isValid())
         return 0;
 
-    const QAbstractProxyModel* proxyModel = dynamic_cast<const QAbstractProxyModel*>(index.model());
-    if(proxyModel) {
+    const QAbstractProxyModel *proxyModel = dynamic_cast<const QAbstractProxyModel *>(index.model());
+    if (proxyModel) {
         //Get original model index, because proxy models destroy the internalPointer
         QModelIndex originalIndex = proxyModel->mapToSource(index);
-        return static_cast<KoResource*>( originalIndex.internalPointer() );
+        return static_cast<KoResource *>(originalIndex.internalPointer());
     }
 
-    return static_cast<KoResource*>( index.internalPointer() );
+    return static_cast<KoResource *>(index.internalPointer());
 }
 
-void KoResourceItemChooser::setKnsrcFile(const QString& knsrcFileArg)
+void KoResourceItemChooser::setKnsrcFile(const QString &knsrcFileArg)
 {
     d->knsrcFile = knsrcFileArg;
 }
@@ -528,7 +526,7 @@ KoResourceItemView *KoResourceItemChooser::itemView() const
     return d->view;
 }
 
-void KoResourceItemChooser::contextMenuRequested(const QPoint& pos)
+void KoResourceItemChooser::contextMenuRequested(const QPoint &pos)
 {
     d->tagManager->contextMenuRequested(currentResource(), pos);
 }
@@ -538,15 +536,18 @@ void KoResourceItemChooser::setViewModeButtonVisible(bool visible)
     d->viewModeButton->setVisible(visible);
 }
 
-QToolButton* KoResourceItemChooser::viewModeButton() const
+QToolButton *KoResourceItemChooser::viewModeButton() const
 {
     return d->viewModeButton;
 }
 
 void KoResourceItemChooser::setSynced(bool sync)
 {
+    if (d->synced == sync)
+        return;
+
     d->synced = sync;
-    KoResourceItemChooserSync* chooserSync = KoResourceItemChooserSync::instance();
+    KoResourceItemChooserSync *chooserSync = KoResourceItemChooserSync::instance();
     if (sync) {
         connect(chooserSync, SIGNAL(baseLenghtChanged(int)), SLOT(baseLengthChanged(int)));
         baseLengthChanged(chooserSync->baseLength());
@@ -560,12 +561,12 @@ void KoResourceItemChooser::baseLengthChanged(int length)
     if (d->synced) {
         int resourceCount = d->model->resourcesCount();
         int width = d->view->width();
-        int maxColums = width/length;
-        int cols = width/(2*length) + 1;
-        while(cols <= maxColums) {
-            int size = width/cols;
-            int rows = ceil(resourceCount/(double)cols);
-            if(rows*size < (d->view->height()-5)) {
+        int maxColums = width / length;
+        int cols = width / (2 * length) + 1;
+        while (cols <= maxColums) {
+            int size = width / cols;
+            int rows = ceil(resourceCount / (double)cols);
+            if (rows * size < (d->view->height() - 5)) {
                 break;
             }
             cols++;
@@ -575,15 +576,15 @@ void KoResourceItemChooser::baseLengthChanged(int length)
     d->view->updateView();
 }
 
-bool KoResourceItemChooser::eventFilter(QObject* object, QEvent* event)
+bool KoResourceItemChooser::eventFilter(QObject *object, QEvent *event)
 {
     if (d->synced && event->type() == QEvent::Wheel) {
-        KoResourceItemChooserSync* chooserSync = KoResourceItemChooserSync::instance();
-        QWheelEvent* qwheel = dynamic_cast<QWheelEvent* >(event);
+        KoResourceItemChooserSync *chooserSync = KoResourceItemChooserSync::instance();
+        QWheelEvent *qwheel = dynamic_cast<QWheelEvent *>(event);
         if (qwheel->modifiers() & Qt::ControlModifier) {
 
             int degrees = qwheel->delta() / 8;
-            int newBaseLength = chooserSync->baseLength() + degrees/15 * 10;
+            int newBaseLength = chooserSync->baseLength() + degrees / 15 * 10;
             chooserSync->setBaseLength(newBaseLength);
             return true;
         }
@@ -591,13 +592,13 @@ bool KoResourceItemChooser::eventFilter(QObject* object, QEvent* event)
     return QObject::eventFilter(object, event);
 }
 
-void KoResourceItemChooser::resizeEvent(QResizeEvent* event)
+void KoResourceItemChooser::resizeEvent(QResizeEvent *event)
 {
     QWidget::resizeEvent(event);
     updateView();
 }
 
-void KoResourceItemChooser::showEvent(QShowEvent* event)
+void KoResourceItemChooser::showEvent(QShowEvent *event)
 {
     QWidget::showEvent(event);
     updateView();
@@ -606,7 +607,7 @@ void KoResourceItemChooser::showEvent(QShowEvent* event)
 void KoResourceItemChooser::updateView()
 {
     if (d->synced) {
-        KoResourceItemChooserSync* chooserSync = KoResourceItemChooserSync::instance();
+        KoResourceItemChooserSync *chooserSync = KoResourceItemChooserSync::instance();
         baseLengthChanged(chooserSync->baseLength());
     }
 }
