@@ -25,18 +25,18 @@
 
 #include <QDebug>
 
-KoResourceItemView::KoResourceItemView( QWidget * parent )
+KoResourceItemView::KoResourceItemView(QWidget *parent)
     : QTableView(parent)
 {
     setSelectionMode(QAbstractItemView::SingleSelection);
     verticalHeader()->hide();
     horizontalHeader()->hide();
-    verticalHeader()->setDefaultSectionSize( 20 );
+    verticalHeader()->setDefaultSectionSize(20);
     setContextMenuPolicy(Qt::DefaultContextMenu);
-    m_viewMode = FIXED_COLUMS;
+    setViewMode(FIXED_COLUMNS);
 }
 
-void KoResourceItemView::resizeEvent( QResizeEvent * event )
+void KoResourceItemView::resizeEvent(QResizeEvent *event)
 {
     QTableView::resizeEvent(event);
     updateView();
@@ -44,27 +44,39 @@ void KoResourceItemView::resizeEvent( QResizeEvent * event )
     emit sigSizeChanged();
 }
 
-bool KoResourceItemView::viewportEvent( QEvent * event )
+bool KoResourceItemView::viewportEvent(QEvent *event)
 {
-    if( event->type() == QEvent::ToolTip && model() )
-    {
-        QHelpEvent *he = static_cast<QHelpEvent*>(event);
+    if (event->type() == QEvent::ToolTip && model()) {
+        QHelpEvent *he = static_cast<QHelpEvent *>(event);
         QStyleOptionViewItem option = viewOptions();
-        QModelIndex index = model()->buddy( indexAt(he->pos()));
-        if( index.isValid() )
-        {
-            option.rect = visualRect( index );
-            m_tip.showTip( this, he->pos(), option, index );
+        QModelIndex index = model()->buddy(indexAt(he->pos()));
+        if (index.isValid()) {
+            option.rect = visualRect(index);
+            m_tip.showTip(this, he->pos(), option, index);
             return true;
         }
     }
 
-    return QTableView::viewportEvent( event );
+    return QTableView::viewportEvent(event);
 }
 
 void KoResourceItemView::setViewMode(KoResourceItemView::ViewMode mode)
 {
     m_viewMode = mode;
+
+    switch (m_viewMode) {
+    case FIXED_COLUMNS:
+        setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff); // Horizontal scrollbar is never needed
+        setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
+        break;
+    case FIXED_ROWS:
+        setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn);
+        setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff); // Vertical scrollbar is never needed
+    default:
+        setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+        setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+    }
+
 }
 
 void KoResourceItemView::selectionChanged(const QItemSelection &selected, const QItemSelection &/*deselected*/)
@@ -72,7 +84,7 @@ void KoResourceItemView::selectionChanged(const QItemSelection &selected, const
     emit currentResourceChanged(selected.indexes().first());
 }
 
-void KoResourceItemView::contextMenuEvent( QContextMenuEvent * event)
+void KoResourceItemView::contextMenuEvent(QContextMenuEvent *event)
 {
     QTableView::contextMenuEvent(event);
     emit contextMenuRequested(event->globalPos());
@@ -80,27 +92,27 @@ void KoResourceItemView::contextMenuEvent( QContextMenuEvent * event)
 
 void KoResourceItemView::updateView()
 {
-    int columnCount = model()->columnCount( QModelIndex() );
-    int rowCount = model()->rowCount( QModelIndex() );
+    int columnCount = model()->columnCount(QModelIndex());
+    int rowCount = model()->rowCount(QModelIndex());
     int rowHeight, columnWidth;
 
-    if (m_viewMode == FIXED_COLUMS) {
+    if (m_viewMode == FIXED_COLUMNS) {
         columnWidth = viewport()->size().width() / columnCount;
 
-        for( int i = 0; i < columnCount; ++i ) {
-            setColumnWidth( i, columnWidth );
+        for (int i = 0; i < columnCount; ++i) {
+            setColumnWidth(i, columnWidth);
         }
-        if ( columnCount > 1) {
-            for( int i = 0; i < rowCount; ++i ) {
-                setRowHeight( i, columnWidth );
+        if (columnCount > 1) {
+            for (int i = 0; i < rowCount; ++i) {
+                setRowHeight(i, columnWidth);
             }
         }
     } else if (m_viewMode == FIXED_ROWS) {
         if (rowCount == 0) return;  // Don't divide by zero
         rowHeight = viewport()->size().height() / rowCount;
 
-        for( int i = 0; i < rowCount; ++i ) {
-            setRowHeight( i, rowHeight );
+        for (int i = 0; i < rowCount; ++i) {
+            setRowHeight(i, rowHeight);
         }
     }
 }
