@@ -233,7 +233,7 @@ public:
     /// the document resource manager we got on construction
     KoDocumentResourceManager *resourceManager() const;
 
-signals:
+Q_SIGNALS:
     void chartTypeChanged(ChartType);
     void updateConfigWidget() const;
 
