@@ -22,13 +22,6 @@
 #include <stdint.h>
 #include <limits.h>
 
-#ifdef Q_WS_X11
-#include <X11/Xlib.h>
-#include <X11/Xatom.h>
-#include <fixx11h.h>
-#include <QX11Info>
-#endif
-
 #include <QFile>
 #include <QSharedPointer>
 
